'use strict'

var util = require('util')

function Plugin(options) {
    var self = function (md) {
        self.options = options
        self.init(md)
    }

    self.__proto__ = Plugin.prototype
    self.id = 'metadata'

    return self
}

util.inherits(Plugin, Function)

Plugin.prototype.init = function (md) {
    md.inline.ruler.before('text', this.id, this.parse.bind(this), {})
    md.renderer.rules[this.id] = this.render.bind(this)
}

export function metadataLinkParser(id, state, silent) {
    let input = state.src;
    if (state.pos === 0 && input.match(/^([A-Za-z0-9 ]+)::/)) {
        let [key, sep, value] = input.split(/::( |$)/)
        console.log(key, value)
        if (key.length === 0) return false;
        if (!silent) {
            let token = state.push(id, '', 0)
            token.meta = {key, value, tag: 'metadata'}
        }
        state.pos = key.length + 3;
        return true
    }
    return false
}

Plugin.prototype.parse = function (state, silent) {
    return metadataLinkParser(this.id, state, silent)
}

Plugin.prototype.render = function (tokens, id, options, env) {
    let {match: link, tag} = tokens[id].meta
    if (tag === 'metadata') {
        let {key, value} = tokens[id].meta
        return '<span class="metadata-key"><a href="/edit/'+key.replace(/ +/g, '_')+'">'+key+'</a></span>: ';
    }
}

export default (options) => {
    return Plugin(options);
}
