import $ from 'jquery'
import qs from 'querystring'
import * as chrono from 'chrono-node'
import moment from 'moment';

function search(element) {
    return {
        element: element,
        search(query) {
            element.classList.add('is-loading')
            let result;
            return startQuery(query)
                .then(res => {
                    element.classList.remove('is-loading', 'is-error')
                    result = res
                    return res
                }).catch(e => {
                    console.log(e)
                    element.classList.add('is-error')
                    return result || []
                })
        }
    }
}

function startQuery(query, opt) {
    opt ||= {internal:true}
    return fetch('/search/?' + qs.encode({q: query}))
        .then(res => res.json())
        .then(data => {
            let actualResult = [];
            if (opt.internal) {
                actualResult.push({
                    ref: query,
                    title: 'Create new page "' + query + '"',
                    line: 'New page',
                    text: 'New page',
                })
                let parseResult = chrono.nl.casual.parse(query)
                if (parseResult.length) {
                    let m = moment(parseResult[0].start.date())
                    actualResult.push({
                        ref: m.format('LL').replace(/\s+/g, '_'),
                        title: m.format('LL'),
                        line: 'Suggested page',
                        text: 'Suggested page'
                    })
                }
            }
            $.each(data.hits, (key, value) => {
                actualResult.push({
                    ref: value.fields.page,
                    title: value.fields.title,
                    line: value.fields.text,
                    text: value.fragments.text[0]
                })
            })
            return actualResult
        })
}

export default {
    search,
    startQuery
};
